@@ -16,6 +16,10 @@ package _unicode_handling;
     else {
         $JSON::can_handle_UTF16_and_utf8 = 1;
 
+       if ($] < 5.007) {
+         $JSON::can_handle_UTF16_and_utf8 = 0;
+       }
+
 #       if ($] > 5.007 and $] < 5.008003) {
 #            $JSON::can_handle_UTF16_and_utf8 = 0;
 #       }
